@@ -32,8 +32,13 @@ methods::setMethod(
 )
 
 
-print.discretization <- function(object) {
-  print(object@best.disc[[1]])
+#' Print for the discretization class.
+#' @rdname print
+#' @method print discretization
+#' @param x S4 discretization object.
+#' @param ... Other print options.
+print.discretization <- function(x, ...) {
+  print(x@best.disc[[1]], ...)
 }
 
 #' Summary
@@ -47,6 +52,7 @@ methods::setGeneric("summary")
 
 #' Summary for the discretization class.
 #' @rdname summary
+#' @method summary discretization
 #' @param object S4 discretization object.
 summary.discretization <- function(object) {
   summary(object@best.disc[[1]])
@@ -71,6 +77,7 @@ methods::setGeneric("predict")
 
 #' Prediction on a raw test set of the best logistic regression model on discretized data.
 #' @rdname predict
+#' @method predict discretization
 #' @param object The S4 discretization object.
 #' @param newdata The test dataframe to discretize and for which we wish to have predictions.
 predict.discretization <- function(object, newdata) {
@@ -90,6 +97,7 @@ predict.discretization <- function(object, newdata) {
 
 #' Prediction on a raw test set of the logistic regression model after reject inference.
 #' @rdname predict
+#' @method predict reject_infered
 #' @param object The S4 reject_infered object.
 #' @param newdata The test dataframe to discretize and for which we wish to have predictions.
 #' @param ... Additional parameters to pass on to base predict.
@@ -147,12 +155,12 @@ is_pROC_installed <- function() {
 #' Different kinds of plots using either plotly (if available) or the standard plot (graphics package).
 #'
 #' @rdname plot
+#' @method plot discretization
 #' @param x S4 discretization object.
 #' @param type Type of plot. For now only "ROC" is supported.
 #' @importFrom magrittr "%>%"
 plot.discretization <- function(x, type) {
   if (is_plotly_installed()) {
-
     # The produced graph depends on the 'type' variable
     if (type == "ROC") {
       if (is_pROC_installed()) {
@@ -263,6 +271,7 @@ plot.discretization <- function(x, type) {
 #' Different kinds of plots using either plotly (if available) or the standard plot (graphics package).
 #'
 #' @rdname plot
+#' @method plot discretization
 methods::setMethod("plot", "discretization", plot.discretization)
 
 #' Generic method "discretize" for discretization objects.
